@@ -918,12 +918,12 @@ gnetwork_udp_datagram_set_property (GObject * object, guint property, const GVal
 	    switch (_gnetwork_get_socket_protocol (GINT_TO_POINTER (udp->_priv->sockfd)))
 	      {
 	      case GNETWORK_PROTOCOL_IPv4:
-		success = (setsockopt (udp->_priv->sockfd, IPPROTO_IP, IP_TTL, (gpointer) ttl,
+		success = (setsockopt (udp->_priv->sockfd, IPPROTO_IP, IP_TTL, GINT_TO_POINTER (ttl),
 				       sizeof (ttl)) >= 0);
 		break;
 	      case GNETWORK_PROTOCOL_IPv6:
 		success = (setsockopt (udp->_priv->sockfd, IPPROTO_IPV6, IPV6_UNICAST_HOPS,
-				       (gpointer) ttl, sizeof (ttl)) >= 0);
+				       GINT_TO_POINTER (ttl), sizeof (ttl)) >= 0);
 		break;
 	      default:
 		g_assert_not_reached ();
@@ -967,7 +967,7 @@ gnetwork_udp_datagram_set_property (GObject * object, guint property, const GVal
 	  return;
 
 	if (udp->_priv->sockfd > 0 &&
-	    setsockopt (udp->_priv->sockfd, SOL_SOCKET, SO_BROADCAST, (gpointer) broadcast,
+	    setsockopt (udp->_priv->sockfd, SOL_SOCKET, SO_BROADCAST, GINT_TO_POINTER (broadcast),
 			sizeof (broadcast)) == -1)
 	  {
 	    if (udp->_priv->port != 0)
